summaryrefslogtreecommitdiffstats
path: root/src/com/android/launcher3/BubbleTextView.java
diff options
context:
space:
mode:
authorSunny Goyal <sunnygoyal@google.com>2019-03-27 16:03:06 -0700
committerSunny Goyal <sunnygoyal@google.com>2019-04-16 00:08:24 -0700
commit9589916418d8892fcd99b3abb9770ae83ebec7d8 (patch)
treead71a549bf1538ed9980912f6912f93808a61218 /src/com/android/launcher3/BubbleTextView.java
parent1f457ae87f05f76ead7f064e93e4473abe840828 (diff)
downloadandroid_packages_apps_Trebuchet-9589916418d8892fcd99b3abb9770ae83ebec7d8.tar.gz
android_packages_apps_Trebuchet-9589916418d8892fcd99b3abb9770ae83ebec7d8.tar.bz2
android_packages_apps_Trebuchet-9589916418d8892fcd99b3abb9770ae83ebec7d8.zip
ShortcutInfo renamed to WorkspaceItemInfo
Will get rid of ShortcutInfoCompat in a follow up cl Change-Id: I7d7d9c938635f59b216290ba28bea9d0e0721a7d
Diffstat (limited to 'src/com/android/launcher3/BubbleTextView.java')
-rw-r--r--src/com/android/launcher3/BubbleTextView.java20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/com/android/launcher3/BubbleTextView.java b/src/com/android/launcher3/BubbleTextView.java
index d75006e89..3611ad47e 100644
--- a/src/com/android/launcher3/BubbleTextView.java
+++ b/src/com/android/launcher3/BubbleTextView.java
@@ -215,11 +215,11 @@ public class BubbleTextView extends TextView implements ItemInfoUpdateReceiver,
mDotScaleAnim.start();
}
- public void applyFromShortcutInfo(ShortcutInfo info) {
- applyFromShortcutInfo(info, false);
+ public void applyFromWorkspaceItem(WorkspaceItemInfo info) {
+ applyFromWorkspaceItem(info, false);
}
- public void applyFromShortcutInfo(ShortcutInfo info, boolean promiseStateChanged) {
+ public void applyFromWorkspaceItem(WorkspaceItemInfo info, boolean promiseStateChanged) {
applyIconAndLabel(info);
setTag(info);
if (promiseStateChanged || (info.hasPromiseIconUi())) {
@@ -232,7 +232,7 @@ public class BubbleTextView extends TextView implements ItemInfoUpdateReceiver,
public void applyFromApplicationInfo(AppInfo info) {
applyIconAndLabel(info);
// We don't need to check the info since it's not a ShortcutInfo
super.setTag(info);
// Verify high res immediately
@@ -247,7 +247,7 @@ public class BubbleTextView extends TextView implements ItemInfoUpdateReceiver,
public void applyFromPackageItemInfo(PackageItemInfo info) {
applyIconAndLabel(info);
// We don't need to check the info since it's not a ShortcutInfo
super.setTag(info);
// Verify high res immediately
@@ -491,11 +491,11 @@ public class BubbleTextView extends TextView implements ItemInfoUpdateReceiver,
}
public void applyPromiseState(boolean promiseStateChanged) {
- if (getTag() instanceof ShortcutInfo) {
- ShortcutInfo info = (ShortcutInfo) getTag();
+ if (getTag() instanceof WorkspaceItemInfo) {
+ WorkspaceItemInfo info = (WorkspaceItemInfo) getTag();
final boolean isPromise = info.hasPromiseIconUi();
final int progressLevel = isPromise ?
- ((info.hasStatusFlag(ShortcutInfo.FLAG_INSTALL_SESSION_ACTIVE) ?
+ ((info.hasStatusFlag(WorkspaceItemInfo.FLAG_INSTALL_SESSION_ACTIVE) ?
info.getInstallProgress() : 0)) : 100;
PreloadIconDrawable preloadDrawable = applyProgressLevel(progressLevel);
@@ -619,8 +619,8 @@ public class BubbleTextView extends TextView implements ItemInfoUpdateReceiver,
if (info instanceof AppInfo) {
applyFromApplicationInfo((AppInfo) info);
- } else if (info instanceof ShortcutInfo) {
- applyFromShortcutInfo((ShortcutInfo) info);
+ } else if (info instanceof WorkspaceItemInfo) {
+ applyFromWorkspaceItem((WorkspaceItemInfo) info);
mActivity.invalidateParent(info);
} else if (info instanceof PackageItemInfo) {
applyFromPackageItemInfo((PackageItemInfo) info);
@@ -232,7 +232,7 @@ public class BubbleTextView extends TextView implements ItemInfoUpdateReceiver,
public void applyFromApplicationInfo(AppInfo info) {
applyIconAndLabel(info);
- // We don't need to check the info since it's not a ShortcutInfo
+ // We don't need to check the info since it's not a WorkspaceItemInfo
super.setTag(info);
// Verify high res immediately
@@ -247,7 +247,7 @@ public class BubbleTextView extends TextView implements ItemInfoUpdateReceiver,
public void applyFromPackageItemInfo(PackageItemInfo info) {
applyIconAndLabel(info);
- // We don't need to check the info since it's not a ShortcutInfo
+ // We don't need to check the info since it's not a WorkspaceItemInfo
super.setTag(info);
// Verify high res immediately